﻿using Hotline.Orders;
using Hotline.Settings;
using SqlSugar;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Hotline.Users;
using XF.Domain.Repository;

namespace Hotline.KnowledgeBase
{
    [Description("知识审核")]
    [SugarIndex("index_order_creationtime", nameof(KnowledgeApprove.CreationTime), OrderByType.Desc)]
    public class KnowledgeApprove : CreationEntity
    {
        /// <summary>
        /// 知识Id
        /// </summary>
        public string KnowledgeId { get; set; }

        /// <summary>
        /// 审核类型
        /// </summary>
        public EKnowledgeApproveType KnowledgeApproveType { get; set; }

        /// <summary>
        /// 审核状态
        /// </summary>
        public EKnowledgeApproveStatus KnowledgeApproveStatus { get; set; }

        /// <summary>
        /// 审批发起意见
        /// </summary>
        public string? CreateOpinion { get; set; }

        /// <summary>
        /// 审批人Id
        /// </summary>
        public string? ApproverId { get; set; }

        /// <summary>
        /// 审核意见
        /// </summary>
        public string? ApproveOpinion { get; set; }

        /// <summary>
        /// 审核时间
        /// </summary>
        public DateTime? ApproveTime { get; set; }

        [Navigate(NavigateType.OneToOne, nameof(KnowledgeId))]
        public Knowledge Knowledge { get; set; }

        /// <summary>
        /// 发起人
        /// </summary>
        [Navigate(NavigateType.OneToOne, nameof(CreatorId))]
        public User Creator { get; set; }

        /// <summary>
        /// 审批人
        /// </summary>
        [Navigate(NavigateType.OneToOne, nameof(ApproverId))]
        public User Approver { get; set; }
    }

    /// <summary>
    /// 审核状态
    /// </summary>
    public enum EKnowledgeApproveStatus
    {
        [Description("待审批")]
        Unhandle = 0,

        [Description("通过")]
        Successed = 1,

        [Description("不通过")]
        Failed = 2,
    }

    /// <summary>
    /// 审核类型
    /// </summary>
    public enum EKnowledgeApproveType
    {
        [Description("新增知识")]
        Add = 0,

        [Description("更新知识")]
        Update = 1,

        [Description("删除知识")]
        Delete = 2,
    }
}
